
# Type: disease to thing association_subject




URI: [biolink:disease_to_thing_association_subject](https://w3id.org/biolink/vocab/disease_to_thing_association_subject)


## Domain and Range

[DiseaseToThingAssociation](DiseaseToThingAssociation.md) ->  <sub>REQ</sub> [Disease](Disease.md)

## Parents

 *  is_a: [subject](subject.md)

## Children

 *  [disease to exposure association➞subject](disease_to_exposure_association_subject.md)

## Used by

 * [DiseaseToThingAssociation](DiseaseToThingAssociation.md)
